scylladb::app::worker

Struct BasicRetryWorker

pub struct BasicRetryWorker<R> {
    pub request: R,
    pub retries: usize,
}
A basic worker which can retry on failure

Fields

request: R

The worker’s request

retries: usize

The number of times this worker will retry on failure

Implementations

Source

impl<R> BasicRetryWorker<R>

pub fn new(request: R) -> Box<Self>

Create a new insert worker with a number of retries