scylladb::cql

Enum ColType

pub enum ColType {
Show 25 variants Custom(String), Ascii, Bigint, Blob, Boolean, Counter, Decimal, Double, Float, Int, Timestamp, Uuid, Varchar, Varint, Timeuuid, Inet, Date, Time, Smallint, Tinyint, List { element: Box<ColType>, }, Map { key: Box<ColType>, value: Box<ColType>, }, Set { element: Box<ColType>, }, Udt { ks: String, udt_name: String, fields: HashMap<String, ColType>, }, Tuple { elements: Vec<ColType>, },
}
The cql column type

Variants



Custom(String)

Custom cql column type



Ascii

Ascii cql column type



Bigint

Bigint cql column type



Blob

Blob cql column type



Boolean

Bool cql column type



Counter

Counter cql column type



Decimal

Decimal cql column type



Double

Double cql column type



Float

Float cql column type



Int

Int cql column type



Timestamp

Timestamp cql column type



Uuid

UUID cql column type



Varchar

Varchar cql column type



Varint

Varint cql column type



Timeuuid

TimeUuid cql column type



Inet

Inet cql column type



Date

Date cql column type



Time

Time cql column type



Smallint

SmallInt cql column type



Tinyint

Tinyint cql column type



List

List cql column type

Fields

element: Box<ColType>

The list elements type



Map

Map collection cql column type

Fields

key: Box<ColType>

The map key type

value: Box<ColType>

The map value key type



Set

Set cql column type

Fields

element: Box<ColType>

The Set elements type



Udt

User defined cql column type

Fields

ks: String

keyspace name this UDT is part of.

udt_name: String

UDT name

fields: HashMap<String, ColType>

UDT Fields where key is the name and value is the type



Tuple

Tuple cql column type

Fields

elements: Vec<ColType>

The Tuple elements type