pub struct Query(pub Vec<u8>);Expand description
The query frame structure.
Tuple Fields
0: Vec<u8>Implementations
Sourceimpl Query
impl Query
Sourcepub fn new() -> QueryBuilder<QueryStatement>
pub fn new() -> QueryBuilder<QueryStatement>
Create CQL query by following the cql binary v4 specs
Sourcepub fn with_capacity(capacity: usize) -> QueryBuilder<QueryStatement>
pub fn with_capacity(capacity: usize) -> QueryBuilder<QueryStatement>
Create CQL query with_capacity by following the cql binary v4 specs
Sourceimpl Query
impl Query
Sourcepub fn from_payload_unchecked(payload: Vec<u8>) -> Query
pub fn from_payload_unchecked(payload: Vec<u8>) -> Query
Create a Query from a payload without validating it. This assumes that the user knows for certain that the payload is a valid Query payload. Otherwise, using it as one will likely cause panics.
Sourcepub fn convert_to_execute(&mut self) -> Result<&mut Self>
pub fn convert_to_execute(&mut self) -> Result<&mut Self>
Convert a Query frame into an Execute frame. Will return an error if the frame is not a Query frame.
Sourcepub fn convert_to_query(&mut self, stmt: &str) -> Result<&mut Query>
pub fn convert_to_query(&mut self, stmt: &str) -> Result<&mut Query>
Convert an Execute frame into a Query frame. Will return an error if the frame is not an Execute frame.