pub struct VoidDecoder;Expand description
VoidDecoder trait to decode the VOID result from scylla
Implementations
Sourceimpl VoidDecoder
impl VoidDecoder
Sourcepub fn try_decode_void(decoder: Decoder) -> Result<()>
pub fn try_decode_void(decoder: Decoder) -> Result<()>
Try to decode the provided Decoder with an expected Void result
Sourcepub fn decode_void(decoder: Decoder)
pub fn decode_void(decoder: Decoder)
Decode the provided Decoder with an deterministic Void result